am 059e4eb3: am f08d230e: SDK: Rename "SDK Setup.exe" to "SDK Manager.exe"

Merge commit '059e4eb3dbcc3ad645a2cd1f1670d92ab3dc1455'

* commit '059e4eb3dbcc3ad645a2cd1f1670d92ab3dc1455':
  SDK: Rename "SDK Setup.exe" to "SDK Manager.exe"
diff --git a/build/tools/make_windows_sdk.sh b/build/tools/make_windows_sdk.sh
index 7df662d..3ceca1f 100755
--- a/build/tools/make_windows_sdk.sh
+++ b/build/tools/make_windows_sdk.sh
@@ -172,10 +172,10 @@
     mkdir -pv "$LIB"/x86_64
     cp -v prebuilt/windows-x86_64/swt/swt.jar  "$LIB"/x86_64/
 
     # Copy the SDK Setup (aka sdklauncher) to the root of the SDK (it was copied in tools above)
     # and move it also in SDK/tools/lib (so that tools updates can update the root one too)
-    cp "$TOOLS/sdklauncher.exe" "$TEMP_SDK_DIR/SDK Setup.exe"
-    mv "$TOOLS/sdklauncher.exe" "$LIB/SDK Setup.exe"
+    cp "$TOOLS/sdklauncher.exe" "$TEMP_SDK_DIR/SDK Manager.exe"
+    mv "$TOOLS/sdklauncher.exe" "$LIB/SDK Manager.exe"
 
     # If you want the emulator NOTICE in the tools dir, uncomment the following line:
     # cp -v external/qemu/NOTICE "$TOOLS"/emulator_NOTICE.txt
@@ -172,10 +172,10 @@
     cp -v prebuilt/windows-x86_64/swt/swt.jar  "$LIB"/x86_64/
 
-    # Copy the SDK Setup (aka sdklauncher) to the root of the SDK (it was copied in tools above)
+    # Copy the SDK Manager (aka sdklauncher) to the root of the SDK (it was copied in tools above)
     # and move it also in SDK/tools/lib (so that tools updates can update the root one too)
diff --git a/build/tools/patch_windows_sdk.sh b/build/tools/patch_windows_sdk.sh
index 1a76817..c28c9d9 100755
--- a/build/tools/patch_windows_sdk.sh
+++ b/build/tools/patch_windows_sdk.sh
@@ -38,10 +38,10 @@
 mkdir -pv $LIB/x86_64
 cp $V ${TOPDIR}prebuilt/windows-x86_64/swt/swt.jar  $LIB/x86_64/
 
 # Copy the SDK Setup (aka sdklauncher) to the root of the SDK (it was copied in tools above)
 # and move it also in SDK/tools/lib (so that tools updates can update the root one too)
-cp $TOOLS/sdklauncher.exe $TEMP_SDK_DIR/"SDK Setup.exe"
-mv $TOOLS/sdklauncher.exe $LIB/"SDK Setup.exe"
+cp $TOOLS/sdklauncher.exe $TEMP_SDK_DIR/"SDK Manager.exe"
+mv $TOOLS/sdklauncher.exe $LIB/"SDK Manager.exe"
 
 # Copy the emulator NOTICE in the tools dir
 cp $V ${TOPDIR}external/qemu/NOTICE $TOOLS/emulator_NOTICE.txt
@@ -38,10 +38,10 @@
 cp $V ${TOPDIR}prebuilt/windows-x86_64/swt/swt.jar  $LIB/x86_64/
 
-# Copy the SDK Setup (aka sdklauncher) to the root of the SDK (it was copied in tools above)
+# Copy the SDK Manager (aka sdklauncher) to the root of the SDK (it was copied in tools above)
 # and move it also in SDK/tools/lib (so that tools updates can update the root one too)